ArgumentD4rtException class

Exception for argument-related errors in D4rt components.

Inheritance

Constructors

ArgumentD4rtException(String message)
Creates a new argument error with the given message.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revoke() bool
Revokes this error from the ErrorReporter.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited