BoundExtensionMethodCallable class

Represents an extension method bound to a target instance.

Stores the instance (target) and the extension method (extensionMethod). When call is invoked, it calls the underlying extension method, automatically inserting the target instance as the first positional argument.

Implemented types

Constructors

BoundExtensionMethodCallable(Object? target, InterpretedExtensionMethod extensionMethod)

Properties

arity int
no setteroverride
extensionMethod InterpretedExtensionMethod
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Object?
final

Methods

call(InterpreterVisitor visitor, List<Object?> positionalArguments, [Map<String, Object?> namedArguments = const {}, List<RuntimeType>? typeArguments = const []]) Object?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited