BridgedEnumDefinition<T extends Enum> class

Constructors

BridgedEnumDefinition({required String name, required List<T> values, Map<String, BridgedInstanceGetterAdapter> getters = const {}, Map<String, BridgedMethodAdapter> methods = const {}})

Properties

getters Map<String, BridgedInstanceGetterAdapter>
Adapters for instance getters on enum values. The key is the getter name.
final
hashCode int
The hash code for this object.
no setterinherited
methods Map<String, BridgedMethodAdapter>
Adapters for instance methods on enum values. The key is the method name.
final
name String
The name under which the enum will be known in the interpreter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<T>
The list of native enum values (e.g. MyEnum.values).
final

Methods

buildBridgedEnum() → BridgedEnum
Builds the BridgedEnum object from this definition.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited