BridgedEnumMixinMethodCallable class

Callable for bridged mixin methods on enum values

Implemented types

Constructors

BridgedEnumMixinMethodCallable(InterpretedEnumValue enumValue, BridgedMethodAdapter adapter, String methodName, String bridgedMixinName)

Properties

adapter BridgedMethodAdapter
final
arity int
no setteroverride
bridgedMixinName String
final
enumValue InterpretedEnumValue
final
hashCode int
The hash code for this object.
no setterinherited
methodName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

call(InterpreterVisitor visitor, List<Object?> positionalArguments, [Map<String, Object?> namedArguments = const {}, List<RuntimeType>? typeArguments]) Object?
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited