BridgedStaticMethodCallable class
Represents a static method from a bridged class that can be passed as a value
- Implemented types
Constructors
- BridgedStaticMethodCallable(BridgedClass _bridgedClass, BridgedStaticMethodAdapter _adapter, String _methodName)
Properties
Methods
-
call(
InterpreterVisitor visitor, List< Object?> positionalArguments, [Map<String, Object?> namedArguments = const {}, List<RuntimeType> ? typeArguments]) → Object? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited