DangerousPermission class

Dangerous permissions that should be granted with extreme caution.

Inheritance

Properties

description String
Human-readable description of what this permission allows.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type of permission (e.g., 'filesystem', 'network', 'process').
final

Methods

allows(dynamic operation) bool
Checks if this permission allows the given operation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

any DangerousPermission
Allows all dangerous operations.
final
codeEvaluation DangerousPermission
Allows evaluation of arbitrary code strings (eval-like functionality).
final
nativePlugins DangerousPermission
Allows loading and executing native plugins/libraries.
final