DeclarationVisitor class
Visitor for the first pass: Declares class and mixin placeholders.
This visitor traverses top-level declarations and creates empty
InterpretedClass instances (placeholders) in the global environment for
each class and mixin found. It does not resolve relationships (extends,
implements, with) nor does it process members.
- Inheritance
-
- Object
- GeneralizingAstVisitor<
void> - DeclarationVisitor
Constructors
- DeclarationVisitor(Environment environment)
Properties
- environment → Environment
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
visitAdjacentStrings(
AdjacentStrings node) → void -
inherited
-
visitAnnotatedNode(
AnnotatedNode node) → void -
inherited
-
visitAnnotation(
Annotation node) → void -
inherited
-
visitArgumentList(
ArgumentList node) → void -
inherited
-
visitAsExpression(
AsExpression node) → void -
inherited
-
visitAssertInitializer(
AssertInitializer node) → void -
inherited
-
visitAssertStatement(
AssertStatement node) → void -
inherited
-
visitAssignedVariablePattern(
AssignedVariablePattern node) → void -
inherited
-
visitAssignmentExpression(
AssignmentExpression node) → void -
inherited
-
visitAwaitExpression(
AwaitExpression node) → void -
inherited
-
visitBinaryExpression(
BinaryExpression node) → void -
inherited
-
visitBlock(
Block node) → void -
inherited
-
visitBlockClassBody(
BlockClassBody node) → void -
inherited
-
visitBlockFunctionBody(
BlockFunctionBody node) → void -
inherited
-
visitBooleanLiteral(
BooleanLiteral node) → void -
inherited
-
visitBreakStatement(
BreakStatement node) → void -
inherited
-
visitCascadeExpression(
CascadeExpression node) → void -
inherited
-
visitCaseClause(
CaseClause node) → void -
inherited
-
visitCastPattern(
CastPattern node) → void -
inherited
-
visitCatchClause(
CatchClause node) → void -
inherited
-
visitCatchClauseParameter(
CatchClauseParameter node) → void -
inherited
-
visitClassBody(
ClassBody node) → void -
inherited
-
visitClassDeclaration(
ClassDeclaration node) → void -
override
-
visitClassMember(
ClassMember node) → void -
inherited
-
visitClassNamePart(
ClassNamePart node) → void -
inherited
-
visitClassTypeAlias(
ClassTypeAlias node) → void -
inherited
-
visitCollectionElement(
CollectionElement node) → void -
inherited
-
visitCombinator(
Combinator node) → void -
inherited
-
visitComment(
Comment node) → void -
inherited
-
visitCommentReferableExpression(
CommentReferableExpression node) → void -
inherited
-
visitCommentReference(
CommentReference node) → void -
inherited
-
visitCompilationUnit(
CompilationUnit node) → void -
inherited
-
visitCompilationUnitMember(
CompilationUnitMember node) → void -
inherited
-
visitConditionalExpression(
ConditionalExpression node) → void -
inherited
-
visitConfiguration(
Configuration node) → void -
inherited
-
visitConstantPattern(
ConstantPattern node) → void -
inherited
-
visitConstructorDeclaration(
ConstructorDeclaration node) → void -
inherited
-
visitConstructorFieldInitializer(
ConstructorFieldInitializer node) → void -
inherited
-
visitConstructorInitializer(
ConstructorInitializer node) → void -
inherited
-
visitConstructorName(
ConstructorName node) → void -
inherited
-
visitConstructorReference(
ConstructorReference node) → void -
inherited
-
visitConstructorSelector(
ConstructorSelector node) → void -
inherited
-
visitContinueStatement(
ContinueStatement node) → void -
inherited
-
visitDartPattern(
DartPattern node) → void -
inherited
-
visitDeclaration(
Declaration node) → void -
inherited
-
visitDeclaredIdentifier(
DeclaredIdentifier node) → void -
inherited
-
visitDeclaredVariablePattern(
DeclaredVariablePattern node) → void -
inherited
-
visitDefaultFormalParameter(
DefaultFormalParameter node) → void -
inherited
-
visitDirective(
Directive node) → void -
inherited
-
visitDoStatement(
DoStatement node) → void -
inherited
-
visitDotShorthandConstructorInvocation(
DotShorthandConstructorInvocation node) → void -
inherited
-
visitDotShorthandInvocation(
DotShorthandInvocation node) → void -
inherited
-
visitDotShorthandPropertyAccess(
DotShorthandPropertyAccess node) → void -
inherited
-
visitDottedName(
DottedName node) → void -
inherited
-
visitDoubleLiteral(
DoubleLiteral node) → void -
inherited
-
visitEmptyClassBody(
EmptyClassBody node) → void -
inherited
-
visitEmptyFunctionBody(
EmptyFunctionBody node) → void -
inherited
-
visitEmptyStatement(
EmptyStatement node) → void -
inherited
-
visitEnumBody(
EnumBody node) → void -
inherited
-
visitEnumConstantArguments(
EnumConstantArguments node) → void -
inherited
-
visitEnumConstantDeclaration(
EnumConstantDeclaration node) → void -
inherited
-
visitEnumDeclaration(
EnumDeclaration node) → void -
override
-
visitExportDirective(
ExportDirective node) → void -
inherited
-
visitExpression(
Expression node) → void -
inherited
-
visitExpressionFunctionBody(
ExpressionFunctionBody node) → void -
inherited
-
visitExpressionStatement(
ExpressionStatement node) → void -
inherited
-
visitExtendsClause(
ExtendsClause node) → void -
inherited
-
visitExtensionDeclaration(
ExtensionDeclaration node) → void -
inherited
-
visitExtensionOnClause(
ExtensionOnClause node) → void -
inherited
-
visitExtensionOverride(
ExtensionOverride node) → void -
inherited
-
visitExtensionTypeDeclaration(
ExtensionTypeDeclaration node) → void -
inherited
-
visitFieldDeclaration(
FieldDeclaration node) → void -
inherited
-
visitFieldFormalParameter(
FieldFormalParameter node) → void -
inherited
-
visitForEachParts(
ForEachParts node) → void -
inherited
-
visitForEachPartsWithDeclaration(
ForEachPartsWithDeclaration node) → void -
inherited
-
visitForEachPartsWithIdentifier(
ForEachPartsWithIdentifier node) → void -
inherited
-
visitForEachPartsWithPattern(
ForEachPartsWithPattern node) → void -
inherited
-
visitForElement(
ForElement node) → void -
inherited
-
visitForLoopParts(
ForLoopParts node) → void -
inherited
-
visitFormalParameter(
FormalParameter node) → void -
inherited
-
visitFormalParameterList(
FormalParameterList node) → void -
inherited
-
visitForParts(
ForParts node) → void -
inherited
-
visitForPartsWithDeclarations(
ForPartsWithDeclarations node) → void -
inherited
-
visitForPartsWithExpression(
ForPartsWithExpression node) → void -
inherited
-
visitForPartsWithPattern(
ForPartsWithPattern node) → void -
inherited
-
visitForStatement(
ForStatement node) → void -
inherited
-
visitFunctionBody(
FunctionBody node) → void -
inherited
-
visitFunctionDeclaration(
FunctionDeclaration node) → void -
override
-
visitFunctionDeclarationStatement(
FunctionDeclarationStatement node) → void -
inherited
-
visitFunctionExpression(
FunctionExpression node) → void -
inherited
-
visitFunctionExpressionInvocation(
FunctionExpressionInvocation node) → void -
inherited
-
visitFunctionReference(
FunctionReference node) → void -
inherited
-
visitFunctionTypeAlias(
FunctionTypeAlias node) → void -
inherited
-
visitFunctionTypedFormalParameter(
FunctionTypedFormalParameter node) → void -
inherited
-
visitGenericFunctionType(
GenericFunctionType node) → void -
inherited
-
visitGenericTypeAlias(
GenericTypeAlias node) → void -
inherited
-
visitGuardedPattern(
GuardedPattern node) → void -
inherited
-
visitHideCombinator(
HideCombinator node) → void -
inherited
-
visitIdentifier(
Identifier node) → void -
inherited
-
visitIfElement(
IfElement node) → void -
inherited
-
visitIfStatement(
IfStatement node) → void -
inherited
-
visitImplementsClause(
ImplementsClause node) → void -
inherited
-
visitImplicitCallReference(
ImplicitCallReference node) → void -
inherited
-
visitImportDirective(
ImportDirective node) → void -
inherited
-
visitImportPrefixReference(
ImportPrefixReference node) → void -
inherited
-
visitIndexExpression(
IndexExpression node) → void -
inherited
-
visitInstanceCreationExpression(
InstanceCreationExpression node) → void -
inherited
-
visitIntegerLiteral(
IntegerLiteral node) → void -
inherited
-
visitInterpolationElement(
InterpolationElement node) → void -
inherited
-
visitInterpolationExpression(
InterpolationExpression node) → void -
inherited
-
visitInterpolationString(
InterpolationString node) → void -
inherited
-
visitInvocationExpression(
InvocationExpression node) → void -
inherited
-
visitIsExpression(
IsExpression node) → void -
inherited
-
visitLabel(
Label node) → void -
inherited
-
visitLabeledStatement(
LabeledStatement node) → void -
inherited
-
visitLibraryDirective(
LibraryDirective node) → void -
inherited
-
visitLibraryIdentifier(
LibraryIdentifier node) → void -
inherited
-
visitListLiteral(
ListLiteral node) → void -
inherited
-
visitListPattern(
ListPattern node) → void -
inherited
-
visitLiteral(
Literal node) → void -
inherited
-
visitLogicalAndPattern(
LogicalAndPattern node) → void -
inherited
-
visitLogicalOrPattern(
LogicalOrPattern node) → void -
inherited
-
visitMapLiteralEntry(
MapLiteralEntry node) → void -
inherited
-
visitMapPattern(
MapPattern node) → void -
inherited
-
visitMapPatternEntry(
MapPatternEntry node) → void -
inherited
-
visitMethodDeclaration(
MethodDeclaration node) → void -
inherited
-
visitMethodInvocation(
MethodInvocation node) → void -
inherited
-
visitMixinDeclaration(
MixinDeclaration node) → void -
override
-
visitMixinOnClause(
MixinOnClause node) → void -
inherited
-
visitNamedCompilationUnitMember(
NamedCompilationUnitMember node) → void -
inherited
-
visitNamedExpression(
NamedExpression node) → void -
inherited
-
visitNamedType(
NamedType node) → void -
inherited
-
visitNamespaceDirective(
NamespaceDirective node) → void -
inherited
-
visitNameWithTypeParameters(
NameWithTypeParameters node) → void -
inherited
-
visitNativeClause(
NativeClause node) → void -
inherited
-
visitNativeFunctionBody(
NativeFunctionBody node) → void -
inherited
-
visitNode(
AstNode node) → void -
inherited
-
visitNormalFormalParameter(
NormalFormalParameter node) → void -
inherited
-
visitNullAssertPattern(
NullAssertPattern node) → void -
inherited
-
visitNullAwareElement(
NullAwareElement node) → void -
inherited
-
visitNullCheckPattern(
NullCheckPattern node) → void -
inherited
-
visitNullLiteral(
NullLiteral node) → void -
inherited
-
visitObjectPattern(
ObjectPattern node) → void -
inherited
-
visitParenthesizedExpression(
ParenthesizedExpression node) → void -
inherited
-
visitParenthesizedPattern(
ParenthesizedPattern node) → void -
inherited
-
visitPartDirective(
PartDirective node) → void -
inherited
-
visitPartOfDirective(
PartOfDirective node) → void -
inherited
-
visitPatternAssignment(
PatternAssignment node) → void -
inherited
-
visitPatternField(
PatternField node) → void -
inherited
-
visitPatternFieldName(
PatternFieldName node) → void -
inherited
-
visitPatternVariableDeclaration(
PatternVariableDeclaration node) → void -
inherited
-
visitPatternVariableDeclarationStatement(
PatternVariableDeclarationStatement node) → void -
inherited
-
visitPostfixExpression(
PostfixExpression node) → void -
inherited
-
visitPrefixedIdentifier(
PrefixedIdentifier node) → void -
inherited
-
visitPrefixExpression(
PrefixExpression node) → void -
inherited
-
visitPrimaryConstructorDeclaration(
PrimaryConstructorDeclaration node) → void -
inherited
-
visitPrimaryConstructorName(
PrimaryConstructorName node) → void -
inherited
-
visitPropertyAccess(
PropertyAccess node) → void -
inherited
-
visitRecordLiteral(
RecordLiteral node) → void -
inherited
-
visitRecordPattern(
RecordPattern node) → void -
inherited
-
visitRecordTypeAnnotation(
RecordTypeAnnotation node) → void -
inherited
-
visitRecordTypeAnnotationField(
RecordTypeAnnotationField node) → void -
inherited
-
visitRecordTypeAnnotationNamedField(
RecordTypeAnnotationNamedField node) → void -
inherited
-
visitRecordTypeAnnotationNamedFields(
RecordTypeAnnotationNamedFields node) → void -
inherited
-
visitRecordTypeAnnotationPositionalField(
RecordTypeAnnotationPositionalField node) → void -
inherited
-
visitRedirectingConstructorInvocation(
RedirectingConstructorInvocation node) → void -
inherited
-
visitRelationalPattern(
RelationalPattern node) → void -
inherited
-
visitRepresentationConstructorName(
RepresentationConstructorName node) → void -
inherited
-
visitRepresentationDeclaration(
RepresentationDeclaration node) → void -
inherited
-
visitRestPatternElement(
RestPatternElement node) → void -
inherited
-
visitRethrowExpression(
RethrowExpression node) → void -
inherited
-
visitReturnStatement(
ReturnStatement node) → void -
inherited
-
visitScriptTag(
ScriptTag node) → void -
inherited
-
visitSetOrMapLiteral(
SetOrMapLiteral node) → void -
inherited
-
visitShowCombinator(
ShowCombinator node) → void -
inherited
-
visitSimpleFormalParameter(
SimpleFormalParameter node) → void -
inherited
-
visitSimpleIdentifier(
SimpleIdentifier node) → void -
inherited
-
visitSimpleStringLiteral(
SimpleStringLiteral node) → void -
inherited
-
visitSingleStringLiteral(
SingleStringLiteral node) → void -
inherited
-
visitSpreadElement(
SpreadElement node) → void -
inherited
-
visitStatement(
Statement node) → void -
inherited
-
visitStringInterpolation(
StringInterpolation node) → void -
inherited
-
visitStringLiteral(
StringLiteral node) → void -
inherited
-
visitSuperConstructorInvocation(
SuperConstructorInvocation node) → void -
inherited
-
visitSuperExpression(
SuperExpression node) → void -
inherited
-
visitSuperFormalParameter(
SuperFormalParameter node) → void -
inherited
-
visitSwitchCase(
SwitchCase node) → void -
inherited
-
visitSwitchDefault(
SwitchDefault node) → void -
inherited
-
visitSwitchExpression(
SwitchExpression node) → void -
inherited
-
visitSwitchExpressionCase(
SwitchExpressionCase node) → void -
inherited
-
visitSwitchMember(
SwitchMember node) → void -
inherited
-
visitSwitchPatternCase(
SwitchPatternCase node) → void -
inherited
-
visitSwitchStatement(
SwitchStatement node) → void -
inherited
-
visitSymbolLiteral(
SymbolLiteral node) → void -
inherited
-
visitThisExpression(
ThisExpression node) → void -
inherited
-
visitThrowExpression(
ThrowExpression node) → void -
inherited
-
visitTopLevelVariableDeclaration(
TopLevelVariableDeclaration node) → void -
override
-
visitTryStatement(
TryStatement node) → void -
inherited
-
visitTypeAlias(
TypeAlias node) → void -
inherited
-
visitTypeAnnotation(
TypeAnnotation node) → void -
inherited
-
visitTypeArgumentList(
TypeArgumentList node) → void -
inherited
-
visitTypedLiteral(
TypedLiteral node) → void -
inherited
-
visitTypeLiteral(
TypeLiteral node) → void -
inherited
-
visitTypeParameter(
TypeParameter node) → void -
inherited
-
visitTypeParameterList(
TypeParameterList node) → void -
inherited
-
visitUriBasedDirective(
UriBasedDirective node) → void -
inherited
-
visitVariableDeclaration(
VariableDeclaration node) → void -
inherited
-
visitVariableDeclarationList(
VariableDeclarationList node) → void -
inherited
-
visitVariableDeclarationStatement(
VariableDeclarationStatement node) → void -
inherited
-
visitVariablePattern(
VariablePattern node) → void -
inherited
-
visitWhenClause(
WhenClause node) → void -
inherited
-
visitWhileStatement(
WhileStatement node) → void -
inherited
-
visitWildcardPattern(
WildcardPattern node) → void -
inherited
-
visitWithClause(
WithClause node) → void -
inherited
-
visitYieldStatement(
YieldStatement node) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited