EnumInfo class

Information about an enum declaration.

Inheritance

Constructors

EnumInfo({required String name, required List<String> values, List<String> methods = const []})
const

Properties

declarationType String
The type of declaration (function, class, variable, enum, extension).
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
methods List<String>
Methods defined in the enum.
final
name String
The name of the declaration.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
The enum values.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited