EnvironmentState class

Represents the current state of the D4rt environment.

This captures what globals and bridged types are currently available in the interpreter's global environment.

Constructors

EnvironmentState({required List<EnvironmentVariableInfo> variables, required List<String> bridgedClasses, required List<String> bridgedEnums})
const

Properties

bridgedClasses List<String>
Bridged classes currently registered in the global environment.
final
bridgedEnums List<String>
Bridged enums currently registered in the global environment.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List<EnvironmentVariableInfo>
Variables currently defined in the global environment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this environment state to a JSON-serializable map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited