ExtensionInfo class
Information about an extension declaration.
- Inheritance
-
- Object
- DeclarationInfo
- ExtensionInfo
Constructors
-
ExtensionInfo({required String name, required String onType, List<
String> methods = const []}) -
const
Properties
- declarationType → String
-
The type of declaration (function, class, variable, enum, extension).
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methods
→ List<
String> -
Methods defined in this extension.
final
- name → String
-
The name of the declaration.
finalinherited
- onType → String
-
The type this extension extends.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited