GlobalFunctionInfo class

Information about a registered global function.

Constructors

GlobalFunctionInfo({required String name, required String libraryUri, String? signature})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
libraryUri String
The library URI that registered this function.
final
name String
The name of the function.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String?
The full signature of the function as a display string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this global function info to a JSON-serializable map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited