InterpretedExtension class

Constructors

InterpretedExtension({String? name, required RuntimeType onType, bool isOnNullableType = false, required Map<String, Callable> members, Map<String, Callable>? staticMethods, Map<String, Callable>? staticGetters, Map<String, Callable>? staticSetters, Map<String, Object?>? staticFields})

Properties

hashCode int
The hash code for this object.
no setterinherited
isOnNullableType bool
final
members Map<String, Callable>
final
name String?
final
onType RuntimeType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staticFields Map<String, Object?>
final
staticGetters Map<String, Callable>
final
staticMethods Map<String, Callable>
final
staticSetters Map<String, Callable>
final

Methods

findMember(String name) Callable?
findStaticGetter(String name) Callable?
findStaticMethod(String name) Callable?
findStaticSetter(String name) Callable?
getStaticField(String name) Object?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setStaticField(String name, Object? value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited