InterpretedExtensionTypeInstance class

An instance of an extension type

Implemented types

Constructors

InterpretedExtensionTypeInstance(InterpretedExtensionType extensionType, Object? representationValue)

Properties

extensionType InterpretedExtensionType
final
hashCode int
The hash code for this object.
no setterinherited
representationValue Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueType RuntimeType
The runtime type of this value.
no setteroverride

Methods

get(String propertyName, [InterpreterVisitor? visitor]) Object?
Get a property (field or getter) on this extension type instance
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String name, Object? value) → void
Sets a property of this value.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited