LibraryExtension class

Wrapper class for library-scoped bridged extensions. Stores a bridged extension definition with its canonical source URI.

Constructors

LibraryExtension(BridgedExtensionDefinition extensionDefinition, {String? sourceUri})
const

Properties

extensionDefinition BridgedExtensionDefinition
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Convenience getter for the extension name.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceUri String?
The canonical source URI where this extension is defined. See LibraryVariable.sourceUri for details.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited