RuntimeValue class abstract

Common interface for values defined at runtime (interpreted or bridged instances).

Implementers

Constructors

RuntimeValue()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueType RuntimeType
The runtime type of this value.
no setter

Methods

get(String name) Object?
Accesses a property or method of this value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String name, Object? value) → void
Sets a property of this value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited