ScriptExecutionResult class
Result of a script execution.
Constructors
- ScriptExecutionResult.failure(String error, {StackTrace? stackTrace, int sourcesLoaded = 0})
-
Create a failed result.
factory
- ScriptExecutionResult.success(Object? result, int sourcesLoaded)
-
Create a successful result.
factory
Properties
- error → String?
-
Error message if execution failed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- result → Object?
-
The result value from execution (if any).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourcesLoaded → int
-
Number of source files loaded (main script + imports).
final
- stackTrace → StackTrace?
-
Stack trace if execution failed.
final
- success → bool
-
Whether the execution was successful.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited