VariableInfo class

Information about a variable declaration.

Inheritance

Constructors

VariableInfo({required String name, String? declaredType, required String valueType, Object? value, bool isFinal = false, bool isConst = false, bool isLate = false})
const

Properties

declarationType String
The type of declaration (function, class, variable, enum, extension).
no setteroverride
declaredType String?
The declared type of the variable, if available.
final
hashCode int
The hash code for this object.
no setterinherited
isConst bool
Whether the variable is const.
final
isFinal bool
Whether the variable is final.
final
isLate bool
Whether the variable is late.
final
name String
The name of the declaration.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
The current value (may be the actual value or a string representation).
final
valueType String
The current runtime type of the value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited