ArgumentD4rtException class
Exception for argument-related errors in D4rt components.
- Inheritance
-
- Object
- D4rtException
- ArgumentD4rtException
Constructors
- ArgumentD4rtException(String message)
- Creates a new argument error with the given message.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revoke(
) → bool -
Revokes this error from the ErrorReporter.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited