BridgedInstance<T extends Object> class
Represents an instance of a bridged native class.
- Implemented types
Constructors
-
BridgedInstance(BridgedClass bridgedClass, T nativeObject, {List<
RuntimeType> typeArguments = const []})
Properties
- bridgedClass → BridgedClass
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nativeObject → T
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
typeArguments
→ List<
RuntimeType> -
final
- valueType → RuntimeType
-
The runtime type of this value.
no setteroverride
Methods
-
get(
String name) → Object? -
Accesses a property or method of this value.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
String name, Object? value, [InterpreterVisitor? visitor]) → void -
Sets a property of this value.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited