BridgedMixinMethodCallable class
Represents a method call on a bridged mixin applied to an interpreted instance.
- Implemented types
Constructors
- BridgedMixinMethodCallable(InterpretedInstance instance, BridgedMethodAdapter adapter, String methodName, String bridgedMixinName)
Properties
- adapter → BridgedMethodAdapter
-
final
- arity → int
-
no setteroverride
- bridgedMixinName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance → InterpretedInstance
-
final
- methodName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
InterpreterVisitor visitor, List< Object?> positionalArguments, [Map<String, Object?> namedArguments = const {}, List<RuntimeType> ? typeArguments]) → Object? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited