D4rtException class abstract

Base class for all D4rt-specific exceptions that should be tracked.

All exceptions are automatically registered with ErrorReporter on creation. If an exception is caught and handled gracefully, call revoke() to prevent it from causing test failures.

Implemented types
Implementers

Constructors

D4rtException(String message)
Creates a D4rtException and registers it with the ErrorReporter.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revoke() bool
Revokes this error from the ErrorReporter.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited