EnvironmentVariableInfo class
Information about a variable in the environment.
Constructors
- EnvironmentVariableInfo({required String name, required String valueType, required bool isNull})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNull → bool
-
Whether the value is null.
final
- name → String
-
The name of the variable.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valueType → String
-
The runtime type of the value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this variable info to a JSON-serializable map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited