ImportConfiguration class
Configuration for a single import library.
Constructors
-
ImportConfiguration({required String importPath, required List<
BridgedClassInfo> classes, required List<BridgedEnumInfo> enums}) -
const
Properties
-
classes
→ List<
BridgedClassInfo> -
List of bridged classes available from this import.
final
-
enums
→ List<
BridgedEnumInfo> -
List of bridged enums available from this import.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- importPath → String
-
The import path (e.g., 'package:tom_core_kernel/tom_core_kernel.dart').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts this import configuration to a JSON-serializable map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited