InterpretedExtensionType class
Lim-1 FIX: Represents an extension type definition at runtime. Extension types are inline classes that provide a zero-cost abstraction.
- Implemented types
Constructors
-
InterpretedExtensionType(String name, String representationFieldName, RuntimeType? representationType, Environment definitionEnvironment, Map<
String, InterpretedFunction> getters, Map<String, InterpretedFunction> methods)
Properties
- arity → int
-
no setteroverride
- definitionEnvironment → Environment
-
final
-
getters
→ Map<
String, InterpretedFunction> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methods
→ Map<
String, InterpretedFunction> -
final
- name → String
-
The name of the type.
final
- representationFieldName → String
-
final
- representationType → RuntimeType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
call(
InterpreterVisitor visitor, List< Object?> positionalArgs, [Map<String, Object?> ? namedArgs, List<RuntimeType> ? typeArguments]) → Object? -
Call creates an instance wrapping the representation value
override
-
isSubtypeOf(
RuntimeType other, {Object? value}) → bool -
Checks if this type is a subtype of
other.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited