InterpretedInstance class
Represents an instance of an InterpretedClass at runtime.
- Implemented types
Constructors
-
InterpretedInstance(InterpretedClass klass, {List<
RuntimeType> ? typeArguments})
Properties
- bridgedSuperObject ↔ Object?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- klass → InterpretedClass
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
typeArguments
→ List<
RuntimeType> ? -
final
- valueType → RuntimeType
-
The runtime type of this value.
no setteroverride
Methods
-
findOperator(
String operatorSymbol) → InterpretedFunction? -
get(
String name, {InterpreterVisitor? visitor}) → Object? -
Accesses a property or method of this value.
override
-
getField(
String name) → Object? -
getTypeArguments(
) → List< RuntimeType> ? - Get the generic type arguments for this instance
-
isValueCompatibleWithTypeArgument(
Object? value, int typeArgumentIndex) → bool - Check if a value is compatible with the expected generic type at the given index
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
String name, Object? value, [InterpreterVisitor? visitor]) → void -
Sets a property of this value.
override
-
toString(
) → String -
A string representation of this object.
override
-
validateFieldAssignment(
String fieldName, Object? value, RuntimeType? expectedType) → void - Validate that a value can be assigned to a field with a specific generic type constraint
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited