LibraryEnum class
Wrapper class for library-scoped bridged enums. Stores a bridged enum with its canonical source URI for deduplication.
Constructors
-
LibraryEnum(BridgedEnumDefinition<
Enum> enumDefinition, {String? sourceUri}) -
const
Properties
-
enumDefinition
→ BridgedEnumDefinition<
Enum> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Convenience getter for the enum name.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceUri → String?
-
The canonical source URI where this enum is defined.
See LibraryVariable.sourceUri for details.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited