LibraryFunction class
Wrapper class for library-scoped functions. Stores a native function with its canonical source URI for deduplication.
Constructors
- LibraryFunction(NativeFunction function, {String? sourceUri, String? signature})
-
const
Properties
- function → NativeFunction
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Convenience getter for the function name.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String?
-
The full signature of the function as a display string.
final
- sourceUri → String?
-
The canonical source URI where this function is defined.
See LibraryVariable.sourceUri for details.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited