ModuleBridgeInfo class
Complete bridge information for a package/module.
Contains both the barrel-to-libraries mappings and the library-to-bridges definitions. This enables complete deduplication at registration time.
Constructors
-
ModuleBridgeInfo({required List<
BarrelMapping> barrelMappings, required Map<String, LibraryBridgeDefinition> libraryBridges}) -
Creates a new module bridge info.
const
Properties
-
barrelMappings
→ List<
BarrelMapping> -
Mappings from barrel URIs to their source libraries.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
libraryBridges
→ Map<
String, LibraryBridgeDefinition> -
Bridge definitions keyed by canonical library URI.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBridgesForLibrary(
String libraryUri) → LibraryBridgeDefinition? - Gets the bridge definition for a library URI.
-
getLibrariesForBarrel(
String barrelUri) → List< String> ? - Gets all source libraries for a barrel URI.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited